<?php
/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization in functions.php file or in the form of a child theme.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */

/**
 * Registers a new admin page, providing content and corresponding menu item for the Social Settings page.
 *
 * @package Somo\Admin
 *
 * @since 1.0.0
 */
class Somo_Admin_Social_Settings extends Genesis_Admin_Boxes {

	/**
	 * Create an admin menu item and settings page.
	 *
	 * @since 1.0.0
	 *
	 * @uses SOMO_SOCIAL_SETTINGS_FIELD Settings field key.
	 * @uses \Genesis_Admin::create()   Create an admin menu item and settings page.
	 */
	function __construct() {

		$page_id = 'somo-social-settings';

		$menu_ops = array(
			'submenu' => array(
				'parent_slug' => 'genesis',
				'page_title' => __( 'Social Settings', 'somo' ),
				'menu_title' => __( 'Social Settings', 'somo' )
			)
		);

		$page_ops = array(
			'screen_icon' => 'somo-screen-icon',
			'save_button_text' => __( 'Save Settings', 'genesis' ),
			'reset_button_text' => __( 'Reset Settings', 'genesis' ),
			'saved_notice_text' => __( 'Settings saved.', 'genesis' ),
			'reset_notice_text' => __( 'Settings reset.', 'genesis' ),
			'error_notice_text' => __( 'Error saving settings.', 'genesis' ),
		);

		$settings_field = SOMO_SOCIAL_SETTINGS_FIELD;

		$default_settings = apply_filters(
			'somo_social_settings_defaults', array(
			'enable_opengraph' => 1,
			'opengraph_publisher_facebook_url' => '',
			'opengraph_default_image_url' => '',
			'fb_insights_meta' => '',
			)
		);

		$this->create( $page_id, $menu_ops, $page_ops, $settings_field, $default_settings );

		add_action( 'genesis_settings_sanitizer_init', array( $this, 'sanitizer_filters' ) );
	}

	/**
	 * Register each of the settings with a sanitization filter type.
	 *
	 * @since 1.0.0
	 *
	 * @uses genesis_add_option_filter() Assign filter to array of settings.
	 *
	 * @see \Genesis_Settings_Sanitizer::add_filter() Add sanitization filters to options.
	 */
	public function sanitizer_filters() {

		genesis_add_option_filter(
			'one_zero', $this->settings_field, array(
			'enable_opengraph',
			)
		);

		genesis_add_option_filter(
			'url', $this->settings_field, array(
			'opengraph_publisher_facebook_url',
			'opengraph_default_image_url',
			)
		);
	}

	/**
	 * Contextual help content.
	 *
	 * @since 2.0.0
	 */
	public function help() {

		$screen = get_current_screen();

		$social_settings_help =
			'<h3>' . __( 'Social Settings', 'somo' ) . '</h3>' .
			'<p>' . __( 'SomoThemes provide powerful social media optimization features like Facebook Open Graph, Facebook Insights, and Google Authorship Integration to boost Social SEO.', 'somo' ) . '</p>' .
			'<p>' . __( 'This feature is polite, and will disable itself when most popular Social SEO plugins (e.g. SEOPressor, WordPress SEO etc.) are active.', 'somo' ) . '</p>' .
			'<p>' . __( 'Below you\'ll find a few succinct notes on the options for each box.', 'somo' ) . '</p>';

		$fb_opengraph_help =
			'<h3>' . __( 'Facebook Open Graph', 'somo' ) . '</h3>' .
			'<p>' . __( 'Facebook Open Graph helps Facebook to identify the image, title, description and other related informaiton about your pages. It is this information that gets displayed in people\'s activity feed when they are using Facebook.', 'somo' ) . '</p>' .
			'<p>' . __( 'SomoThemes ensure that the images, titles, and descriptions are accurately picked up when Facebook crawls your pages. Selecting "Enable Open Graph Markup" option will add Facebook Open Graph meta tags to your website.', 'somo' ) . '</p>' .
			'<p>' . __( 'Provide your Facebook Page URL so that it can be linked to your site. The URL should point to the your/publisher\'s Facebook Page. When displayed in the news feed, Facebook may offer the ability to like the publisher.', 'somo' ) . '</p>' .
			'<p>' . __( 'Provide a default Image URL for Open Graph Meta - an image URL which should represent your home page on Facebook. The image must be at least 200px by 200px and have a maximum aspect ratio of 3:1. PNG, JPEG and GIF formats are supported. This image will also be used for Open Graph meta on archive pages and on those posts/pages not having a featured image attached.', 'somo' ) . '</p>';

		$fb_insights_help =
			'<h3>' . __( 'Facebook Insights', 'somo' ) . '</h3>' .
			'<p>' . __( 'Facebook Insights is a free service provided by Facebook. You can use it to study the Facebook statistics for your website. To get started, go to <a href="https://www.facebook.com/insights/" target="_blank">Facebook Insights</a> and click on the green button on top right that says "Insights for your Website". On the box that appears, type in your website domain URL next to "Domain" and choose "[Your Name] (You)" from the drop-down next to "Link With". Then copy the displayed meta tag and paste it in the option provided. Save the changes and go back to Facebook insights on Facebook and click on Check Domain. Once verified, you will be able to see your Facebook Insights on the Insights dashboard.', 'somo' ) . '</p>' .
			'<p>' . __( 'If your WordPress blog is not installed at the root of the domain/subdomain or if you are using a network installation, you should instead put this meta tag in the head section on the root domain/subdomain homepage.', 'somo' ) . '</p>';

		$authorship_help =
			'<h3>' . __( 'Google Authorship', 'somo' ) . '</h3>' .
			'<p>' . sprintf( __( "SomoThemes integrate Google Authorship Markup automatically for your site. All you need to is to update your Google+ profile link in your author profile settings i.e. %s.", 'somo' ), '<i>' . __( 'WordPress > Users > Your Profile > Social Profile Settings > Google+ URL', 'somo' ) ) . '</i></p>' .
			'<p>' . sprintf( __( '<a href="%s" target="_blank">Learn More</a>', 'somo' ), 'http://somothemes.com/tutorials/google-authorship/' ) . '</p>';

		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-social-settings',
			'title' => __( 'Introduction', 'somo' ),
			'content' => $social_settings_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-fb_opengraph',
			'title' => __( 'Facebook Open Graph', 'somo' ),
			'content' => $fb_opengraph_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-fb_insights',
			'title' => __( 'Facebook Insights', 'somo' ),
			'content' => $fb_insights_help,
		) );
		$screen->add_help_tab( array(
			'id' => $this->pagehook . '-authorship',
			'title' => __( 'Google Authorship', 'somo' ),
			'content' => $authorship_help,
		) );

		//* Add help sidebar
		$screen->set_help_sidebar(
			'<p><strong>' . __( 'For more information:', 'somo' ) . '</strong></p>' .
			'<p><a href="http://somothemes.com/support/" target="_blank" title="' . __( 'Get Support', 'somo' ) . '">' . __( 'Get Support', 'somo' ) . '</a></p>' .
			'<p><a href="http://somothemes.com/tutorials/" target="_blank" title="' . __( 'SomoThemes Tutorials', 'somo' ) . '">' . __( 'SomoThemes Tutorials', 'somo' ) . '</a></p>' .
			'<p><a href="http://somothemes.com/themes/" target="_blank" title="' . __( 'More Themes', 'somo' ) . '">' . __( 'More Themes', 'somo' ) . '</a></p>'
		);
	}

	/**
	 * Register meta boxes on the Social Settings page.
	 *
	 * @since 1.0.0
	 *
	 * @see \Somo_Admin_Social_Settings::opengraph_box()			Callback for Facebook Open Graph box.
	 * @see \Somo_Admin_Social_Settings::facebook_insights_box()	Callback for Facebook Insights box.
	 * @see \Somo_Admin_Social_Settings::twitter_cards_box()		Callback for Twitter Cards box.
	 * @see \Somo_Admin_Social_Settings::google_authorship_box()	Callback for Google Authorship box.
	 */
	function metaboxes() {

		add_meta_box( 'somo-social-settings-opengraph', __( 'Facebook Open Graph', 'somo' ), array( $this, 'opengraph_box' ), $this->pagehook, 'main' );
		add_meta_box( 'somo-social-settings-fb-insights', __( 'Facebook Insights', 'somo' ), array( $this, 'facebook_insights_box' ), $this->pagehook, 'main' );
//		add_meta_box( 'somo-social-settings-twitter-cards', __( 'Twitter Cards', 'somo' ), array( $this, 'twitter_cards_box' ), $this->pagehook, 'main' );
		add_meta_box( 'somo-social-settings-google-authorship', __( 'Google Authorship Markup', 'somo' ), array( $this, 'google_authorship_box' ), $this->pagehook, 'main' );
	}

	/**
	 * Callback for Social Settings Facebook Open Graph meta box.
	 *
	 * @since 1.0.0
	 *
	 * @uses \Genesis_Admin::get_field_id()    Construct field ID.
	 * @uses \Genesis_Admin::get_field_name()  Construct field name.
	 * @uses \Genesis_Admin::get_field_value() Retrieve value of key under $this->settings_field.
	 *
	 * @see \Somo_Admin_Social_Settings::metaboxes() Register meta boxes on the Social Settings page.
	 */
	function opengraph_box() {
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'enable_opengraph' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'enable_opengraph' ); ?>" id="<?php echo $this->get_field_id( 'enable_opengraph' ); ?>" value="1" <?php checked( $this->get_field_value( 'enable_opengraph' ) ); ?> />
				<?php printf( __( 'Enable Open Graph Markup', 'somo' ), genesis_code( 'rel' ) ); ?></label>
		</p>
		<div id="somo_opengraph_setting">
			<p>
				<label for="<?php echo $this->get_field_id( 'opengraph_publisher_facebook_url' ); ?>"><?php _e( 'Your Facebook Page URL:', 'somo' ); ?></label>
				<input type="text" name="<?php echo $this->get_field_name( 'opengraph_publisher_facebook_url' ); ?>" id="<?php echo $this->get_field_id( 'opengraph_publisher_facebook_url' ); ?>" value="<?php echo esc_attr( $this->get_field_value( 'opengraph_publisher_facebook_url' ) ); ?>" size="60" />
			</p>
			<p><span class="description"><?php printf( __( "For example - %s", 'somo' ), genesis_code( 'https://www.facebook.com/somothemes' ) ); ?></span></p>
			<p><span class="description"><?php _e( 'The URL should point to the your/publisher\'s Facebook Page. When displayed in the news feed, Facebook may offer the ability to like the publisher.', 'somo' ); ?></span></p>

			<p>
				<label for="<?php echo $this->get_field_id( 'opengraph_default_image_url' ); ?>"><?php _e( 'Default Image URL for Open Graph Meta:', 'somo' ); ?></label>
				<input type="text" name="<?php echo $this->get_field_name( 'opengraph_default_image_url' ); ?>" id="<?php echo $this->get_field_id( 'opengraph_default_image_url' ); ?>" value="<?php echo esc_attr( $this->get_field_value( 'opengraph_default_image_url' ) ); ?>" size="60" />
			</p>
			<p><span class="description"><?php printf( __( "For example - %s", 'somo' ), genesis_code( 'http://yoursite.com/images/my_image_200x200.png' ) ); ?></span></p>
			<p><span class="description"><?php _e( 'An image URL which should represent your home page on Facebook. The image must be at least 200px by 200px and have a maximum aspect ratio of 3:1. PNG, JPEG and GIF formats are supported. This image will also be used for Open Graph meta on archive pages and on those posts/pages not having a featured image attached.', 'somo' ); ?></span></p>
		</div>
		<?php
	}

	/**
	 * Callback for Social Settings Facebook Insights meta box.
	 *
	 * @since 1.0.0
	 *
	 * @uses \Genesis_Admin::get_field_id()    Construct field ID.
	 * @uses \Genesis_Admin::get_field_name()  Construct field name.
	 * @uses \Genesis_Admin::get_field_value() Retrieve value of key under $this->settings_field.
	 *
	 * @see \Somo_Admin_Social_Settings::metaboxes() Register meta boxes on the Social Settings page.
	 */
	function facebook_insights_box() {
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'fb_insights_meta' ); ?>"><?php _e( 'Facebook Insights Meta Tag:', 'somo' ); ?></label>
			<input type="text" name="<?php echo $this->get_field_name( 'fb_insights_meta' ); ?>" id="<?php echo $this->get_field_id( 'fb_insights_meta' ); ?>" value="<?php echo esc_attr( $this->get_field_value( 'fb_insights_meta' ) ); ?>" size="73" />
		</p>
		<p><span class="description"><?php printf( __( "For example - %s", 'somo' ), genesis_code( '&lt;meta property="fb:admins" content="123456789" /&gt;' ) ); ?></span></p>
		<p><span class="description"><?php _e( 'Facebook Insights is a free service provided by Facebook. You can use it to study the Facebook statistics for your website. To get started, go to <a href="https://www.facebook.com/insights/" target="_blank">Facebook Insights</a> and click on the green button on top right that says "Insights for your Website". On the box that appears, type in your website domain URL next to "Domain" and choose "[Your Name] (You)" from the drop-down next to "Link With". Then copy the displayed meta tag and paste it above. Save the changes and go back to Facebook insights on Facebook and click on Check Domain. Once verified, you will be able to see your Facebook Insights on the Insights dashboard.', 'somo' ); ?></span></p>
		<p><span class="description"><?php _e( 'Note: If your WordPress blog is not installed at the root of the domain/subdomain or if you are using a network installation, you should instead put this meta tag in the head section on the root domain/subdomain homepage.', 'somo' ); ?></span></p>

		<?php
	}

	/**
	 * Callback for Social Settings Google Authorship meta box.
	 *
	 * @since 1.0.0
	 *
	 * @see \Somo_Admin_Social_Settings::metaboxes() Register meta boxes on the Social Settings page.
	 */
	function google_authorship_box() {
		?>
		<p><span class="description">
				<?php
				printf( __( "SomoThemes integrate Google Authorship Markup automatically for your site. All you need to is to update your Google+ profile link in your author profile settings i.e. %s.", 'somo' ), __( 'WordPress > Users > Your Profile > Social Profile Settings > Google+ URL', 'somo' ) );
				printf( __( ' <a href="%s" target="_blank">Learn More</a>', 'somo' ), 'http://somothemes.com/tutorials/google-authorship/' );
				?>
			</span>
		</p>
		<?php
	}

}

