<?php

/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization in functions.php file or in the form of a child theme.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */
add_filter( 'http_request_args', 'somo_disable_wporg_request', 5, 2 );

/**
 * Disable update check request to wp.org theme repository for this theme
 *
 * @link http://markjaquith.wordpress.com/2009/12/14/excluding-your-plugin-or-theme-from-update-checks/
 * @since 1.0.0
 */
function somo_disable_wporg_request( $r, $url ) {

	/* WP.org theme update check URL */
	$wp_url_string = 'api.wordpress.org/themes/update-check';

	/* If it's not a theme update check request, bail early */
	if ( false === strpos( $url, $wp_url_string ) ) {
		return $r;
	}

	/* Get this theme slug (active theme) */
	$theme_slug_template = get_option( 'template' );
	$theme_slug = get_option( 'stylesheet' );

	/* Get response body (json/serialize data) */
	$r_body = wp_remote_retrieve_body( $r );

	/* Get theme request */
	$r_themes = '';
	$r_themes_json = false;
	if ( isset( $r_body[ 'themes' ] ) ) {

		/* Check if data can be serialized */
		if ( is_serialized( $r_body[ 'themes' ] ) ) {
			/* unserialize data ( PRE WP 3.7 ) */
			$r_themes = @unserialize( $r_body[ 'themes' ] );
			$r_themes = ( array ) $r_themes; //make sure it's an array
		} else {
			/* if unserialize didn't work ( POST WP.3.7 using json ) */
			/* use json decode to make body request to array */
			$r_themes = json_decode( $r_body[ 'themes' ], true );
			$r_themes_json = true;
		}
	}

	/* check if themes request is not empty */
	if ( !empty( $r_themes ) ) {

		/* Unset this theme */
		if ( true === $r_themes_json ) { // json encode data
			unset( $r_themes[ 'themes' ][ $theme_slug_template ] );
			unset( $r_themes[ 'themes' ][ $theme_slug ] );
			$r[ 'body' ][ 'themes' ] = json_encode( $r_themes );
		} else { // serialize data
			unset( $r_themes[ $theme_slug ] );
			unset( $r_themes[ $theme_slug_template ] );
			$r[ 'body' ][ 'themes' ] = serialize( $r_themes );
		}
	}

//	/* unserialize data */
//	$themes = unserialize( $r[ 'body' ][ 'themes' ] );
//
//	/* unset this theme only */
//	unset( $themes[ get_option( 'template' ) ] );
//	unset( $themes[ get_option( 'stylesheet' ) ] );
//
//	/* serialize it back */
//	$r[ 'body' ][ 'themes' ] = serialize( $themes );
	return $r;
}

add_filter( 'site_transient_update_themes', 'somo_update_push' );
add_filter( 'transient_update_themes', 'somo_update_push' );

/**
 * Integrate the Genesis update check into the WordPress update checks.
 *
 * This function filters the value that is returned when WordPress tries to pull theme update transient data.
 *
 * It uses `somo_update_check()` to check to see if we need to do an update, and if so, adds the proper array to the
 * `$value->response` object. WordPress handles the rest.
 *
 * @since 1.1.0
 *
 * @uses somo_update_check() Ping http://api.genesistheme.com/ asking if a new version of this theme is available.
 *
 * @param object $value
 *
 * @return object
 */
function somo_update_push( $value ) {

	$somo_update = somo_update_check();

	if ( $somo_update )
		$value->response[ SOMO_PARENT_THEME_SLUG ] = $somo_update;

	return $value;
}

/**
 * Check if a new version of this theme is available.
 *
 * If not, it returns false.
 *
 * If so, the external server passes serialized data back to this function, which gets unserialized and returned for use.
 *
 * Applies `somo_update_remote_post_args` filter.
 *
 * Ping occurs at a maximum of once every 24 hours.
 *
 * @since 1.0.0
 *
 * @uses genesis_get_option() Get theme setting value.
 * @uses SOMO_PARENT_THEME_VERSION Theme version string.
 *
 * @global string $wp_version WordPress version string.
 *
 * @return mixed Unserialized data, or false on failure.
 */
function somo_update_check() {

	//* If updates are disabled
	if ( !genesis_get_option( 'update' ) || !current_theme_supports( 'somo-auto-updates' ) )
		return false;

	$api_username = get_site_option( 'somo_updates_api_username', '' );
	$api_key = get_site_option( 'somo_updates_api_key', '' );
	$api_status = get_site_option( 'somo_updates_api_status', '' );

	if ( '1' !== $api_status )
		return false;

	//* Get time of last update check
	$somo_update = get_transient( 'somo-update' );

	//* If it has expired, do an update check
	if ( !$somo_update ) {
		$remote_url = add_query_arg( array(
			'theme_package' => SOMO_PARENT_THEME_SLUG,
			'package_action' => 'update_check',
			), SOMO_UPDATES_API_ROOT );

		$user_agent = is_multisite() ? 'WordPress MS' : 'WordPress';
		$user_agent .= '/' . $GLOBALS[ 'wp_version' ] . '; ' . home_url();

		$remote_post_data = array(
			'package_version' => SOMO_PARENT_THEME_VERSION,
			'wp_version' => $GLOBALS[ 'wp_version' ],
			'php_version' => phpversion(),
			'user' => $api_username,
			'key' => md5( $api_key ),
		);

		$remote_post_args = apply_filters(
			'somo_update_remote_post_args', array(
			'timeout' => ( ( defined( 'DOING_CRON' ) && DOING_CRON ) ? 30 : 10 ),
			'body' => apply_filters( 'somo_update_remote_post_data', $remote_post_data ),
			'user-agent' => $user_agent,
			)
		);

		$raw_response = wp_remote_post( $remote_url, $remote_post_args );
		$somo_update = wp_remote_retrieve_body( $raw_response );

		//* If an error occurred, return FALSE, store for 1 hour
		if ( '' === $somo_update || 200 !== wp_remote_retrieve_response_code( $raw_response ) || !is_serialized( $somo_update ) ) {
			set_transient( 'somo-update', array(
				'new_version' => SOMO_PARENT_THEME_VERSION,
				'package' => '', //Download URL
				'url' => SOMO_PARENT_THEME_URL, //Theme or Changelog URL
				), HOUR_IN_SECONDS );
			return false;
		}

		//* Else, unserialize
		$somo_update = maybe_unserialize( $somo_update );

		//* And store in transient for 24 hours
		set_transient( 'somo-update', $somo_update, DAY_IN_SECONDS );
	}

	//* If we're already using the latest version, return false
	if ( version_compare( SOMO_PARENT_THEME_VERSION, $somo_update[ 'new_version' ], '>=' ) )
		return false;

	return $somo_update;
}

function somo_validate_api_key( $api_username, $api_key ) {

	$remote_url = add_query_arg( array(
		'theme_package' => SOMO_PARENT_THEME_SLUG,
		'package_action' => 'validate_key',
		), SOMO_UPDATES_API_ROOT );

	$user_agent = is_multisite() ? 'WordPress MS' : 'WordPress';
	$user_agent .= '/' . $GLOBALS[ 'wp_version' ] . '; ' . home_url();

	$remote_post_data = array(
		'user' => $api_username,
		'key' => md5( $api_key ),
	);

	$remote_post_args = apply_filters(
		'somo_validate_api_key_remote_post_args', array(
		'body' => $remote_post_data,
		'user-agent' => $user_agent,
		)
	);

	$raw_response = wp_remote_post( $remote_url, $remote_post_args );
	$response = wp_remote_retrieve_body( $raw_response );

	if ( 200 == wp_remote_retrieve_response_code( $raw_response ) && 'valid' == $response ) {
		return true;
	}

	return false;
}

add_action( 'admin_init', 'somo_upgrade', 20 );

/**
 * Update Theme to the latest version.
 *
 * This iterative update function will take a Genesis installation, no matter
 * how old, and update its options to the latest version.
 *
 * It used to iterate over theme version, but now uses a database version
 * system, which allows for changes within pre-releases, too.
 *
 * @since 1.0.0
 *
 * @return null Return early if we're already on the latest version.
 */
function somo_upgrade() {
	//*somo_upgrade()
	$somo_upgrade_site = get_site_option( 'somo_upgrade_site_' . SOMO_PARENT_THEME_SLUG, false, false );
	if ( !$somo_upgrade_site ) {
		$somo_upgrade_site = genesis_get_option( 'db_version', null, false );
		update_site_option( 'somo_upgrade_site_' . SOMO_PARENT_THEME_SLUG, $somo_upgrade_site );
	}

	//* Don't do anything if we're on the latest version
	if ( genesis_get_option( 'db_version', null, false ) >= SOMO_PARENT_DB_VERSION )
		return;

	if ( genesis_get_option( 'db_version', null, false ) < SOMO_PARENT_DB_VERSION )
		somo_upgrade_db();

	do_action( 'somo_upgrade' );
}

add_action( 'wpmu_upgrade_site', 'somo_network_upgrade_site' );

/**
 * Run silent upgrade on each site in the network during a network upgrade.
 *
 * Update Somo database settings for all sites in a network during network upgrade process.
 *
 * @since 1.0.0
 *
 * @param int $blog_id Blog ID.
 */
function somo_network_upgrade_site( $blog_id ) {

	switch_to_blog( $blog_id );
	$upgrade_url = add_query_arg( array( 'action' => 'somo-silent-upgrade' ), admin_url( 'admin-ajax.php' ) );
	restore_current_blog();

	wp_remote_get( $upgrade_url );
}

add_action( 'wp_ajax_no_priv_somo-silent-upgrade', 'somo_silent_upgrade' );

//add_filter( 'pre_update_site_option_wpmu_upgrade_site', 'update_site_option_somo_upgrade_site', 10, 2 );
//
///**
// * Updates network value for somo db version after the netowrk upgrade process is complete
// *
// * @since 1.0.0
// *
// * @param type $option
// * @param type $value
// * @param type $oldvalue
// * @return type
// */
//function update_site_option_somo_upgrade_site( $value, $oldvalue ) {
//	update_site_option( 'somo_upgrade_site_' . SOMO_PARENT_THEME_SLUG, SOMO_PARENT_DB_VERSION );
//	return $value;
//}

/**
 * Genesis settings upgrade. Silent upgrade (no redirect).
 *
 * Meant to be called via ajax request during network upgrade process.
 *
 * @since 1.0.0
 *
 * @uses genesis_upgrade() Update Genesis to the latest version.
 */
function somo_silent_upgrade() {

	remove_action( 'somo_upgrade', 'somo_upgrade_redirect' );
	somo_upgrade();
	exit( 0 );
}

add_action( 'somo_upgrade', 'somo_upgrade_redirect' );

/**
 * Redirect the user back to the theme settings page, refreshing the data and notifying the user that they have
 * successfully updated.
 *
 * @since 1.0.0
 *
 * @uses genesis_admin_redirect() Redirect the user to an admin page, and add query args to the URL string for alerts.
 *
 * @return null Returns early if not an admin page.
 */
function somo_upgrade_redirect() {

	if ( !is_admin() || !current_user_can( 'edit_theme_options' ) )
		return;

	if ( get_transient( '_somo_activated' ) ) {
		delete_transient( '_somo_activated' );
		genesis_admin_redirect( 'somo-welcome' );
		exit;
	}

	genesis_admin_redirect( 'somo-about' );
	exit;
}

add_action( 'admin_init', 'somo_activation_redirect' );

function somo_activation_redirect() {
	global $pagenow;
	if ( is_admin() && isset( $_GET[ 'activated' ] ) && $pagenow == 'themes.php' ) {
		_genesis_update_settings( array(
			'theme_version' => '0',
			'db_version' => '0',
		) );
		set_transient( '_somo_activated', 1, MINUTE_IN_SECONDS );
		genesis_admin_redirect( 'somo-welcome' );
		exit;
	}
}

add_action( 'admin_notices', 'somo_upgraded_notice' );

/**
 * Displays the notice that the theme settings were successfully updated to the latest version.
 *
 * Currently only used for pre-release update notices.
 *
 * @since 1.2.0
 *
 * @uses genesis_get_option()   Get theme setting value.
 * @uses genesis_is_menu_page() Check that we're targeting a specific Genesis admin page.
 *
 * @return null Returns early if not on the Theme Settings page.
 */
function somo_upgraded_notice() {
	if ( !genesis_is_menu_page( 'genesis' ) )
		return;

	if ( isset( $_REQUEST[ 'upgraded' ] ) &&
		'true' === $_REQUEST[ 'upgraded' ] )
		echo '<div id="message" class="updated highlight" id="message"><p><strong>' . sprintf( __( 'Congratulations! You are now running %s %s', 'somo' ), esc_html( SOMO_PARENT_THEME_NAME ), genesis_get_option( 'theme_version' ) ) . '</strong></p></div>';
}

//function somo_network_upgrade_notice() {
//	if ( !is_super_admin() )
//		return false;
//
//	$somo_upgrade_site = get_site_option( 'somo_upgrade_site_' . SOMO_PARENT_THEME_SLUG );
//	if ( $somo_upgrade_site && $somo_upgrade_site != SOMO_PARENT_DB_VERSION )
//		echo "<div class='update-nag'>" . sprintf( __( 'Thank you for Updating %s! Please visit the <a href="%s">Upgrade Network</a> page to update all your sites.', 'somo' ), esc_html( SOMO_PARENT_THEME_NAME ), esc_url( network_admin_url( 'upgrade.php' ) ) ) . "</div>";
//}
//
//add_action( 'admin_notices', 'somo_network_upgrade_notice' );

add_filter( 'update_theme_complete_actions', 'genesis_update_action_links', 10, 2 );

/**
 * Filter the action links at the end of an update.
 *
 * This function filters the action links that are presented to the user at the end of a theme update. If the theme
 * being updated is not Genesis, the filter returns the default values. Otherwise, it will provide a link to the
 * Genesis Theme Settings page, which will trigger the database upgrade.
 *
 * @since 1.1.3
 *
 * @param array  $actions Existing array of action links.
 * @param string $theme   Theme name.
 *
 * @return string Removes all existing action links in favour of a single link, if Genesis.
 */
function genesis_update_action_links( array $actions, $theme ) {

	if ( SOMO_PARENT_THEME_SLUG !== $theme /* || is_network_admin() */ )
		return $actions;

	if ( is_network_admin() ) {
		//** menu_page_url does not seem to work correctly on network admin (WP 3.6), hence this hack
		$upgrade_url = add_query_arg( array( 'page' => 'genesis' ), admin_url( 'admin.php' ) );
		return sprintf( '<a href="%s">%s</a>', $upgrade_url, __( 'Click here to complete the upgrade', 'somo' ) );
	} else {
		return sprintf( '<a href="%s">%s</a>', menu_page_url( 'genesis', 0 ), __( 'Click here to complete the upgrade', 'somo' ) );
	}
}

add_action( 'admin_notices', 'somo_update_nag' );

/**
 * Display the update nag at the top of the dashboard if there is a Genesis update available.
 *
 * @since 1.1.0
 *
 * @uses somo_update_check() Ping http://api.genesistheme.com/ asking if a new version of this theme is available.
 *
 * @return boolean Return false if there is no available update, or user is not a site administrator.
 */
function somo_update_nag() {
	global $pagenow;
	$somo_update = somo_update_check();

	if ( !is_super_admin() || !
		$somo_update || 'update.php' == $pagenow )
		return false;

	echo '<div id="update-nag">';
	printf(
		__( '%s %s is available. <a href="%s" %s>Check out what\'s new</a> or <a href="%s" %s>update now.</a>', 'somo' ), esc_html( SOMO_PARENT_THEME_NAME ), esc_html( $somo_update[ 'new_version' ] ), esc_url( $somo_update[ 'url' ] ), 'class="thickbox thickbox-preview"', wp_nonce_url( 'update.php?action=upgrade-theme&amp;theme=' . SOMO_PARENT_THEME_SLUG, 'upgrade-theme_' . SOMO_PARENT_THEME_SLUG ), 'class="genesis-js-confirm-upgrade"' );
	echo '</div>';
}

add_action( 'init', 'genesis_update_email' );

/**
 * Sends out update notification email.
 *
 * Does several checks before finally sending out a notification email to the
 * specified email address, alerting it to a Genesis update available for that install.
 *
 * @since 1.1.0
 *
 * @uses genesis_get_option()  Get theme setting value.
 * @uses somo_update_check() Ping http://api.genesistheme.com/ asking if a new version of this theme is available.
 *
 * @return null Returns null if email should not be sent.
 */
function genesis_update_email() {

	//* Pull email options from DB
	$email_on = genesis_get_option( 'update_email' );
	$email = genesis_get_option( 'update_email_address' );

//* If we're not supposed to send an email, or email is blank / invalid, stop!
	if
	( !$email_on || !is_email( $email ) )
		return;

	//* Check for updates
	$update_check = somo_update_check();

//* If no new version is available, stop!
	if ( !$update_check )
		return;

//* If we've already sent an email for this version, stop!
	if ( get_option( 'somo-update-email' ) === $update_check[ 'new_version' ] )
		return;

	//* Let's send an email!
	$subject = sprintf( __( '%s %s is available for %s', 'somo' ), esc_html( SOMO_PARENT_THEME_NAME ), esc_html( $update_check[ 'new_version' ] ), home_url() );
	$message = sprintf( __( '%s %s is now available. We have provided 1-click updates for this theme, so please log into your dashboard and update at your earliest convenience.', 'somo' ), esc_html( SOMO_PARENT_THEME_NAME ), esc_html( $update_check[ 'new_version' ] ) );
	$message .= "\n\n" . wp_login_url();

//* Update the option so we don't send emails on every pageload!
	update_option( 'somo-update-email', $update_check[ 'new_version' ], TRUE );

	//* Send the email
	wp_mail( sanitize_email( $email ), $subject, $message );
}

add_action( 'load-update-core.php', 'somo_clear_update_transient' );
add_action( 'load-themes.php', 'somo_clear_update_transient' );

/**
 * Delete Theme update transient after updates or when viewing the themes page.
 *
 * The server will then do a fresh version check.
 *
 * It also disables the update nag on those pages as well.
 *
 * @since 1.0.0
 *
 * @see genesis_update_nag()
 */
function somo_clear_update_transient() {

	delete_transient( 'somo-update' );
	remove_action(
		'admin_notices', 'somo_update_nag' );
}

function somo_upgrade_db() {
	if ( function_exists( 'somo_upgrade_db_' . str_replace( '-', '_', SOMO_PARENT_THEME_SLUG ) ) ) {
		call_user_func( 'somo_upgrade_db_' . str_replace( '-', '_', SOMO_PARENT_THEME_SLUG ) );
	} else {
		if ( genesis_get_option( 'db_version', null, false ) < '1000' ) {
			//* Update Settings
			_genesis_update_settings( array(
				'theme_version' => '1.0.0',
				'db_version' => '1000',
			) );
		}
	}
	update_site_option( 'somo_upgrade_site_' . SOMO_PARENT_THEME_SLUG, SOMO_PARENT_DB_VERSION );
}
