<?php

/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization in functions.php file.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */

/**
 * Return Social options from the Social options database.
 *
 * @since 1.0.0
 *
 * @uses genesis_get_option() Return option from the options table and cache result.
 * @uses SOMO_SOCIAL_SETTINGS_FIELD
 *
 * @param string  $key       Option name.
 * @param boolean $use_cache Optional. Whether to use the Genesis cache value or not. Defaults to true.
 *
 * @return mixed The value of this $key in the database.
 */
function somo_get_social_option( $key, $use_cache = true ) {
	return genesis_get_option( $key, SOMO_SOCIAL_SETTINGS_FIELD, $use_cache );
}

/**
 * Get Gravatar.com avatar image URL
 *
 * @since 1.0.0
 *
 * @param string $email		Email address
 * @param string $default	Default Profile Image URL
 * @return string			Gravatar.com avatar URL
 */
function somo_get_avatar_url( $email, $default ) {
	$size = 96;
	if ( !empty( $email ) )
		$email_hash = md5( strtolower( $email ) );

	if ( is_ssl() ) {
		$host = 'https://secure.gravatar.com';
	} else {
		if ( !empty( $email ) ) {
			$host = sprintf( "http://%d.gravatar.com", ( hexdec( $email_hash[ 0 ] ) % 2 ) );
		}
		else
			$host = 'http://0.gravatar.com';
	}

	if ( !empty( $email ) ) {
		$out = "$host/avatar/";
		$out .= $email_hash;
		$out .= '?s=' . $size;

		$rating = get_option( 'avatar_rating' );
		if ( !empty( $rating ) )
			$out .= "&amp;r={$rating}";
	} else {
		$out = $default;
	}
	return $out;
}

/**
 * Add Social Profiles with Authorship Markup to Author boxes
 *
 * @since 1.0.0
 *
 * @uses get_the_author_meta				Get the author meta
 * @uses somo_get_author_box_social_title	Get the author box Social title
 * @uses somo_get_author_social_profiles	Get the social profile links for the author
 *
 * @param string $author_id		Author ID
 * @param string $context		Context - single or archive
 * @return string				HTML formatted author box social profiles section
 */
function somo_add_author_social_profiles( $author_id, $context = 'single' ) {

	if ( ( 'single' === $context && '1' === get_the_author_meta( 'social_author_social_profiles_single', $author_id ) ) ||
		( 'archive' === $context && '1' === get_the_author_meta( 'social_author_social_profiles_archive', $author_id ) ) ) {
		$html = '<div class="author-box-social">';
		$html .= somo_get_author_box_social_title( $author_id, $context );
		$html .= '<ul class="author-box-social-list">';
		$html .= somo_get_author_social_profiles( $author_id, $context );
		$html .= '</ul></div>';
	} else {
		$html = '';
	}
	return $html;
}

/**
 * Retrieve Social Profiles from the Author Profile Settings. Applies somo_get_author_social_profiles filter to the output.
 *
 * @since 1.0.0
 *
 * @uses get_the_author_meta				Get the author meta
 * @uses somo_get_the_social_profile		Get single social profile link for the author
 *
 * @param type $author_id		Author ID
 * @param type $context			Context - single or archive
 * @return string				HTML formatted author box social profiles
 */
function somo_get_author_social_profiles( $author_id, $context = 'single' ) {

	$twitter = get_the_author_meta( 'social_author_twitter_profile', $author_id );
	$facebook = get_the_author_meta( 'social_author_facebook_profile', $author_id );
	$googleplus = get_the_author_meta( 'social_author_gplus_profile', $author_id );
	$pinterest = get_the_author_meta( 'social_author_pinterest_profile', $author_id );
	$linkedin = get_the_author_meta( 'social_author_linkedin_profile', $author_id );
	$youtube = get_the_author_meta( 'social_author_youtube_profile', $author_id );

	$html = $twitter ? '<li class="author-social-profiles social-profile-twitter">' . somo_get_the_social_profile( 'twitter', $twitter, 'Twitter', 'me' ) . '</li>' : '';
	$html .= $facebook ? '<li class="author-social-profiles social-profile-facebook">' . somo_get_the_social_profile( 'facebook', $facebook, 'Facebook', 'me' ) . '</li>' : '';
	$html .= $googleplus ? '<li class="author-social-profiles social-profile-googleplus">' . somo_get_the_social_profile( 'googleplus', $googleplus, 'Google+', 'me' ) . '</li>' : '';
	$html .= $pinterest ? '<li class="author-social-profiles social-profile-pinterest">' . somo_get_the_social_profile( 'pinterest', $pinterest, 'Pinterest', 'me' ) . '</li>' : '';
	$html .= $linkedin ? '<li class="author-social-profiles social-profile-linkedin">' . somo_get_the_social_profile( 'linkedin', $linkedin, 'LinkedIn', 'me' ) . '</li>' : '';
	$html .= $youtube ? '<li class="author-social-profiles social-profile-youtube">' . somo_get_the_social_profile( 'youtube', $youtube, 'YouTube', 'me' ) . '</li>' : '';

	return apply_filters( 'somo_get_author_social_profiles', $html, $author_id, $context );
}

/**
 * Return html formatted link to Social Profiles with Authorship markup. Applies somo_get_the_social_profile filter to the output.
 *
 * @since 1.0.0
 *
 * @param string $service		Social media network identifier
 * @param string $url			Social profile URL
 * @param string $text			Display text
 * @param string $rel			Rel markup value. default rel=me
 * @return string				Formatted html output for single social profile
 */
function somo_get_the_social_profile( $service, $url, $text = '', $rel = 'me' ) {

	$html = '<a href="' . $url . '" rel="' . $rel . '">' . $text . '</a>';
	return apply_filters( 'somo_get_the_social_profile', $html, $service, $url, $text, $rel );
}

/**
 * Return Title for Social Author box. Applies somo_get_author_box_social_title filter to the output.
 *
 * @since 1.0.0
 *
 * @param string $author_id		Author ID
 * @param string $context		Context - single or archive
 * @return string				itle for Social Author box
 */
function somo_get_author_box_social_title( $author_id, $context ) {

	$title = __( 'Connect with', 'social' ) . ' ' . get_the_author_meta( 'display_name', $author_id );
	$html = '<h2 class="author-box-social-title"><span>' . $title . '</span></h2>';
	return apply_filters( 'somo_get_author_box_social_title', $html, $title, $author_id, $context );
}

/**
 * Detect some SOCIAL SEO Plugins that add constants, classes or functions.
 *
 * Applies `somo_detect_social_seo_plugins` filter to allow third party manipulation of Social SEO plugin list.
 *
 * @since 1.0.0
 *
 * @uses genesis_detect_plugin() Detect active plugin by constant, class or function existence.
 *
 * @return boolean True if plugin exists or false if plugin constant, class or function not detected.
 */
function somo_detect_social_seo_plugins() {
	return genesis_detect_plugin(
		// Use this filter to adjust plugin tests.
		apply_filters(
			'somo_detect_social_seo_plugins',
			//* Add to this array to add new plugin checks.
			array(
		// Classes to detect.
		'classes' => array(
			'WPPostsRateKeys', //SEOPressor plugin
			'wpSEO',
		),
		// Functions to detect.
		'functions' => array( ),
		// Constants to detect.
		'constants' => array( 'WPSEO_VERSION', ),
			)
		)
	);
}

/**
 * Disable the Social SEO features.
 *
 * @since 1.0.0
 *
 * @uses SOMO_SOCIAL_SETTINGS_FIELD
 */
function somo_disable_social_seo() {

	remove_filter( 'language_attributes', 'somo_add_ogp_namespaces' );
	remove_filter( 'genesis_attr_htmlns', 'somo_attributes_htmlns' );
	remove_action( 'genesis_meta', 'somo_meta' );

	remove_theme_support( 'somo-social-settings-menu' );
	add_filter( 'pre_option_' . SOMO_SOCIAL_SETTINGS_FIELD, '__return_empty_array' );

	define( 'SOMO_SOCIAL_SEO_DISABLED', true );
}

add_action( 'after_setup_theme', 'somo_social_seo_compatibility_check', 5 );

/**
 * Check for the existence of popular Social SEO plugins and disable the Social SEO features if one or more of the plugins
 * is active.
 *
 * Runs before the menu is built, so we can disable Social Settings menu, if necessary.
 *
 * @since 1.0.0
 *
 * @see genesis_default_title()
 *
 * @uses somo_detect_social_seo_plugins() Detect certain Social SEO plugins.
 * @uses somo_disable_social_seo()        Disable all aspects of Social SEO features.
 */
function somo_social_seo_compatibility_check() {
	if ( somo_detect_social_seo_plugins() )
		somo_disable_social_seo();
}

/**
 * Hack to insert Theme Settings links on Manage Themes page
 *
 * @since 1.0.0
 *
 */
add_action( 'all_admin_notices', 'somo_add_theme_page' );

function somo_add_theme_page() {
	global $submenu, $pagenow;

	if ( 'themes.php' != $pagenow )
		return;

	$submenu[ 'themes.php' ][ ] = array( __( 'Theme Settings' ), 'edit_theme_options', 'genesis' );
	ksort( $submenu[ 'themes.php' ], SORT_NUMERIC );
}

function somo_get_membersite_url( $page = '' ) {
	return esc_url( 'http://one.somothemes.com/' . $page );
}

