<?php

/**
 * Somo Framework.
 *
 * WARNING: This file is part of the Somo Framework. DO NOT edit this file under any circumstances.
 * Please make the desired customization via functions.php file or in the form of a child theme.
 *
 * @author  SomoThemes
 * @license GPL-2.0+
 * @link    http://somothemes.com/
 */
add_filter( 'language_attributes', 'somo_add_ogp_namespaces' );

/**
 * Modify the opening markup for Open Graph
 * Add Open Graph and Facebook related namespaces
 *
 * @since 1.0.0
 *
 * @uses somo_get_social_option
 * @uses genesis_attr
 *
 * @param string $html			Existing HTML
 * @return string $html			Amended HTML with OGP namespaces
 */
function somo_add_ogp_namespaces( $html ) {
	if ( '1' === somo_get_social_option( 'enable_opengraph' ) ) {
		$html .= ' ' . genesis_attr( 'htmlns' );
	}
	return $html;
}

add_filter( 'genesis_attr_htmlns', 'somo_attributes_htmlns' );

/**
 * Add attributes for html element.
 *
 * @since 1.0.0
 *
 * @param array $attributes Existing attributes.
 * @return array Amended attributes.
 */
function somo_attributes_htmlns( $attributes ) {

	if ( isset( $attributes[ 'class' ] ) )
		unset( $attributes[ 'class' ] );

	$attributes[ 'xmlns:fb' ] = 'http://www.facebook.com/2008/fbml';
	$attributes[ 'xmlns:og' ] = 'http://ogp.me/ns#';

	return $attributes;
}

add_action( 'genesis_meta', 'somo_meta' );

/**
 * Add meta tags to HTML header.
 *
 * @since 1.0.0
 *
 * @uses genesis_get_seo_option
 * @uses somo_get_social_option
 * @uses somo_add_prev_next_meta
 * @uses somo_add_opengraph_meta
 */
function somo_meta() {
	if ( '1' === genesis_get_seo_option( 'head_instant_pages' ) ) {
		remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0 );
		echo somo_add_prev_next_meta();
	} elseif ( !genesis_get_seo_option( 'head_adjacent_posts_rel_link' ) ) {
		remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0 );
	}

	if ( '1' === somo_get_social_option( 'enable_opengraph' ) ) {
		echo somo_add_opengraph_meta();
	}
}

/**
 * Generate relational meta tags for output to HTML header for faster page loads. Applies somo_add_prev_next_meta filter to the output.
 *
 * @since 1.0.0
 *
 * @uses get_query_var
 * @uses get_next_posts_page_link
 * @uses get_previous_posts_page_link
 * @uses get_adjacent_post
 * @uses get_permalink
 *
 * @global WP_Query $wp_query	Query object.
 * @global WP_Post $post		Post object.
 * @param string $html			Existing HTML
 * @return string $html			Amended HTML
 */
function somo_add_prev_next_meta( $html = '' ) {

	global $wp_query, $post;

	$max = intval( $wp_query->max_num_pages );

	if ( ( is_archive() || is_home() ) && ( 1 < $max ) ) {
		$paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
		$next = get_next_posts_page_link();
		$prev = get_previous_posts_page_link();

		if ( 1 < $paged && !empty( $prev ) ) {
			/** rel=prev link for hinting search engines */
			$html .= '<link rel="prev" href="' . $prev . '" />' . "\n";
		}

		if ( $max > $paged && !empty( $next ) ) {
			/** rel=next link for hinting search engines */
			$html .= '<link rel="next" href="' . $next . '" />' . "\n";
			/** Instant Pages for Google Chrome */
			$html .= '<link rel="prerender" href="' . $next . '" />' . "\n";
			/** Prefetch for Firefox */
			$html .= '<link rel="prefetch" href="' . $next . '" />' . "\n";
		}
	} elseif ( is_page_template( 'page_blog.php' ) ) {
		$paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
		$next = get_next_posts_page_link();
		$prev = get_previous_posts_page_link();

		if ( 1 < $paged && !empty( $prev ) ) {
			/** rel=prev link for hinting search engines */
			$html .= '<link rel="prev" href="' . $prev . '" />' . "\n";
		}

		if ( !empty( $next ) ) {
			/** rel=next link for hinting search engines */
			$html .= '<link rel="next" href="' . $next . '" />' . "\n";
			/** Instant Pages for Google Chrome */
			$html .= '<link rel="prerender" href="' . $next . '" />' . "\n";
			/** Prefetch for Firefox */
			$html .= '<link rel="prefetch" href="' . $next . '" />' . "\n";
		}
	} elseif ( is_single() ) {
		$prev = get_adjacent_post( false, '', false );
		$next = get_adjacent_post( false, '', true );

		if ( !empty( $prev ) ) {
			$prev = get_permalink( $prev );
			/** rel=prev link for hinting search engines */
			$html .= '<link rel="prev" href="' . $prev . '" />' . "\n";
		}

		if ( !empty( $next ) ) {
			$next = get_permalink( $next );
			/** rel=next link for hinting search engines */
			$html .= '<link rel="next" href="' . $next . '" />' . "\n";

			/** Instant Pages for Google Chrome */
			$html .= '<link rel="prerender" href="' . $next . '" />' . "\n";

			/** Prefetch for Firefox */
			$html .= '<link rel="prefetch" href="' . $next . '" />' . "\n";
		}
	}

	return apply_filters( 'somo_add_prev_next_meta', $html );
}

/**
 * Generate Open Graph meta tags for output to HTML header. Applies somo_add_opengraph_meta filter to the output.
 *
 * @since 1.0.0
 *
 * @uses genesis_get_seo_option
 * @uses somo_get_social_option
 * @uses get_bloginfo
 * @uses get_permalink
 * @uses get_term_link
 * @uses get_the_author_meta
 * @uses get_query_var
 * @uses somo_get_avatar_url
 * @uses get_author_posts_url
 * @uses genesis_get_custom_field
 * @uses genesis_get_image
 * @uses get_year_link
 * @uses get_month_link
 * @uses get_day_link
 *
 * @global WP_Query $wp_query	Query object.
 * @global WP_Post $post		Post object.
 * @global mixed $paged			paged variable
 * @param string $html			Existing HTML
 * @return string $html			Amended HTML
 */
function somo_add_opengraph_meta( $html = '' ) {
	global $wp_query, $post, $paged;
	if ( ( is_home() || is_front_page() ) && 1 >= $paged ) {
		$title = genesis_get_seo_option( 'home_doctitle' ) ? genesis_get_seo_option( 'home_doctitle' ) : get_bloginfo( 'name' );
		$description = genesis_get_seo_option( 'home_description' ) ? genesis_get_seo_option( 'home_description' ) : get_bloginfo( 'description' );
		$image_url = somo_get_social_option( 'opengraph_default_image_url' );

		$fb_insights_meta = somo_get_social_option( 'fb_insights_meta' );
		if ( !empty( $fb_insights_meta ) )
			$html .= $fb_insights_meta . "\n";

		$html .= '<meta property="og:title" content="' . $title . '" />' . "\n";
		$html .= '<meta property="og:type" content="website" />' . "\n";
		$html .= '<meta property="og:url" content="' . trailingslashit( home_url() ) . '" />' . "\n";
		if ( !empty( $image_url ) )
			$html .= '<meta property="og:image" content="' . esc_url( $image_url ) . '" />' . "\n";
		$html .= '<meta property="og:site_name" content="' . get_bloginfo( 'name' ) . '" />' . "\n";
		$html .= '<meta property="og:description" content="' . esc_attr( $description ) . '" />' . "\n";
	}
	elseif ( is_category() || is_tag() ) {
		$term = $wp_query->get_queried_object();
		$title = !empty( $term->meta[ 'doctitle' ] ) ? $term->meta[ 'doctitle' ] : $term->name . ' ' . __( 'Archives', 'genesis' );
		$description = !empty( $term->meta[ 'description' ] ) ? $term->meta[ 'description' ] : '';
		$image_url = somo_get_social_option( 'opengraph_default_image_url' );
		$publisher_url = somo_get_social_option( 'opengraph_publisher_facebook_url' );

		$html .= '<meta property="og:title" content="' . $title . '" />' . "\n";
		$html .= '<meta property="og:type" content="article" />' . "\n";
		$html .= '<meta property="og:url" content="' . get_term_link( $term ) . '" />' . "\n";
		if ( !empty( $image_url ) )
			$html .= '<meta property="og:image" content="' . esc_url( $image_url ) . '" />' . "\n";
		$html .= '<meta property="og:site_name" content="' . get_bloginfo( 'name' ) . '" />' . "\n";
		if ( !empty( $description ) )
			$html .= '<meta property="og:description" content="' . esc_attr( $description ) . '" />' . "\n";
		if ( !empty( $publisher_url ) )
			$html .= '<meta property="article:publisher" content="' . esc_url( $publisher_url ) . '" />' . "\n";
	}
	elseif ( is_author() ) {
		$user_title = get_the_author_meta( 'doctitle', ( int ) get_query_var( 'author' ) );
		$title = $user_title ? $user_title : get_the_author_meta( 'display_name', ( int ) get_query_var( 'author' ) );

		$user_description = get_the_author_meta( 'meta_description', ( int ) get_query_var( 'author' ) );
		$description = $user_description ? $user_description : '';

		$author_image_url = somo_get_avatar_url( get_the_author_meta( 'user_email', ( int ) get_query_var( 'author' ) ), somo_get_social_option( 'opengraph_default_image_url' ) );

		$html .= '<meta property="og:title" content="' . $title . '" />' . "\n";
		$html .= '<meta property="og:type" content="author" />' . "\n";
		$html .= '<meta property="og:url" content="' . get_author_posts_url( ( int ) get_query_var( 'author' ) ) . '" />' . "\n";
		if ( !empty( $author_image_url ) )
			$html .= '<meta property="og:image" content="' . esc_url( $author_image_url ) . '" />' . "\n";
		$html .= '<meta property="og:site_name" content="' . get_bloginfo( 'name' ) . '" />' . "\n";
		if ( !empty( $description ) )
			$html .= '<meta property="og:description" content="' . esc_attr( $description ) . '" />' . "\n";
	}
	elseif ( is_single() || is_page() ) {
		$title = genesis_get_custom_field( '_genesis_title' ) ? genesis_get_custom_field( '_genesis_title' ) : $post->post_title;
		$description = genesis_get_custom_field( '_genesis_description' ) ? genesis_get_custom_field( '_genesis_description' ) : '';

		$image_url = genesis_get_image( array(
			'format' => 'url',
			'size' => 'feature-thumbnail',
			'num' => 0,
			'attr' => '' ) );
		if ( empty( $image_url ) )
			$image_url = somo_get_social_option( 'opengraph_default_image_url' );

		$publisher_url = somo_get_social_option( 'opengraph_publisher_facebook_url' );
		$author_facebook_url = get_the_author_meta( 'social_author_facebook_profile', ( int ) $post->post_author );
		if ( empty( $author_facebook_url ) )
			$author_facebook_url = $publisher_url;

		if ( !empty( $title ) )
			$html .= '<meta property="og:title" content="' . $title . '" />' . "\n";
		$type = 'article';
		$html .= '<meta property="og:type" content="' . $type . '" />' . "\n";
		$html .= '<meta property="og:url" content="' . get_permalink() . '" />' . "\n";
		if ( !empty( $image_url ) )
			$html .= '<meta property="og:image" content="' . esc_url( $image_url ) . '" />' . "\n";
		$html .= '<meta property="og:site_name" content="' . get_bloginfo( 'name' ) . '" />' . "\n";
		if ( !empty( $description ) )
			$html .= '<meta property="og:description" content="' . esc_attr( $description ) . '" />' . "\n";
		if ( !empty( $publisher_url ) )
			$html .= '<meta property="article:publisher" content="' . esc_url( $publisher_url ) . '" />' . "\n";
		if ( !empty( $author_facebook_url ) )
			$html .= '<meta property="article:author" content="' . $author_facebook_url . '" />' . "\n";
	}
	elseif ( is_date() || is_day() ) {
		$period = get_query_var( 'm' );
		$year = '1970';
		$month = '01';
		$day = '01';
		if ( strlen( $period ) == 4 ) {
			$year = $period;
		}
		if ( strlen( $period ) == 6 ) {
			$year = substr( $period, 0, 4 );
			$month = substr( $period, 4, 2 );
			$period = $year . '/' . $month;
		}
		if ( strlen( $period ) == 8 ) {
			$year = substr( $period, 0, 4 );
			$month = substr( $period, 4, 2 );
			$day = substr( $period, 6, 2 );
			$period = $year . '/' . $month . '/' . $day;
		}

		$title = !empty( $period ) ? __( 'Archives for', 'genesis' ) . ' ' . $period : __( 'Archives', 'genesis' );
		$description = !empty( $period ) ? __( 'Archives for', 'genesis' ) . ' ' . $period . ' | ' . get_bloginfo( 'name' ) : __( 'Archives', 'genesis' ) . ' | ' . get_bloginfo( 'name' );
		$image_url = somo_get_social_option( 'opengraph_default_image_url' );
		$publisher_url = somo_get_social_option( 'opengraph_publisher_facebook_url' );

		if ( is_year() )
			$url = get_year_link( $year );
		elseif ( is_month() )
			$url = get_month_link( $year, $month );
		elseif ( is_day() )
			$url = get_day_link( $year, $month, $day );

		$html .= '<meta property="og:title" content="' . $title . '" />' . "\n";
		$html .= '<meta property="og:type" content="article" />' . "\n";
		$html .= '<meta property="og:url" content="' . $url . '" />' . "\n";
		$html .= '<meta property="og:image" content="' . esc_url( $image_url ) . '" />' . "\n";
		$html .= '<meta property="og:site_name" content="' . get_bloginfo( 'name' ) . '" />' . "\n";
		$html .= '<meta property="og:description" content="' . esc_attr( $description ) . '" />' . "\n";
		if ( !empty( $publisher_url ) )
			$html .= '<meta property="article:publisher" content="' . esc_url( $publisher_url ) . '" />' . "\n";
	}

	return apply_filters( 'somo_add_opengraph_meta', $html );
}
